# Changelog

## [1.0.0] - 2023-06-??

### Added
- Ability to split fasta files into n number of files

## [1.1.0] - 2023-06-??

### Added
- Ability to split fasta files by number of sequences

## [1.2.0] - 2023-06-??

### Added
- Ability to split each sequence in fasta file to separate file

## [1.2.2] - 2023-07-??

### Fixed
- Formatting errors
### Added
- Checks for large numbers of output files

## [1.2.6] - 2023-07-08

### Changed
- **breaking:** Now installs with pip

## [1.2.7] - 2023-07-10

### Added
- Documentation for pypi

## [1.2.8] - 2023-07-10

### Changed
- Formatting in source

## [1.3.0] - 2023-07-25

### Added
- Ability to use stdin for input
